from .Interaction import Interaction
from ..UtilityAndView.abaqusConstants import *


class FluidExchange(Interaction):
    """The FluidExchange object is used to define fluid exchange between two fluid cavities or
    between a fluid cavity and its environment.
    The FluidExchange object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - FLUID EXCHANGE
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the FluidExchange object is created.
    createStepName: str

    #: A String specifying the first FluidCavity object associated with this interaction. This
    #: will be the only cavity specified if **definition** = TO_ENVIRONMENT.
    firstCavity: str

    #: A String specifying the FluidExchangeProperty object associated with this interaction.
    interactionProperty: str

    #: A SymbolicConstant specifying the type of fluid exchange to be defined. Possible values
    #: are TO_ENVIRONMENT and BETWEEN_CAVITIES. The default value is TO_ENVIRONMENT.
    definition: SymbolicConstant = TO_ENVIRONMENT

    #: A String specifying the second FluidCavity object associated with this interaction. This
    #: argument is applicable only when **definition** = BETWEEN_CAVITIES.
    secondCavity: str = ""

    #: A Float specifying the effective exchange area. The default value is 1.0.
    exchangeArea: float = 1

    def __init__(
        self,
        name: str,
        createStepName: str,
        firstCavity: str,
        interactionProperty: str,
        definition: SymbolicConstant = TO_ENVIRONMENT,
        secondCavity: str = "",
        exchangeArea: float = 1,
    ):
        """This method creates an FluidExchange object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].FluidExchange

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the FluidExchange object is created.
        firstCavity
            A String specifying the first FluidCavity object associated with this interaction. This
            will be the only cavity specified if **definition** = TO_ENVIRONMENT.
        interactionProperty
            A String specifying the FluidExchangeProperty object associated with this interaction.
        definition
            A SymbolicConstant specifying the type of fluid exchange to be defined. Possible values
            are TO_ENVIRONMENT and BETWEEN_CAVITIES. The default value is TO_ENVIRONMENT.
        secondCavity
            A String specifying the second FluidCavity object associated with this interaction. This
            argument is applicable only when **definition** = BETWEEN_CAVITIES.
        exchangeArea
            A Float specifying the effective exchange area. The default value is 1.0.

        Returns
        -------
        FluidExchange
            A :py:class:`~abaqus.Interaction.FluidExchange.FluidExchange` object.
        """
        super().__init__()

    def setValues(
        self,
        definition: SymbolicConstant = TO_ENVIRONMENT,
        secondCavity: str = "",
        exchangeArea: float = 1,
    ):
        """This method modifies the FluidExchange object.

        Parameters
        ----------
        definition
            A SymbolicConstant specifying the type of fluid exchange to be defined. Possible values
            are TO_ENVIRONMENT and BETWEEN_CAVITIES. The default value is TO_ENVIRONMENT.
        secondCavity
            A String specifying the second FluidCavity object associated with this interaction. This
            argument is applicable only when **definition** = BETWEEN_CAVITIES.
        exchangeArea
            A Float specifying the effective exchange area. The default value is 1.0.
        """
        ...



from ..UtilityAndView.abaqusConstants import *


class StopCondition:
    """The StopCondition object is the abstract base type for other StopCondition objects. The
    StopCondition object has no explicit constructor. The methods and members of the
    StopCondition object are common to all objects derived from StopCondition.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].stopConditions[name]
    """

    #: A String specifying the stop condition repository key.
    name: str = ""

    #: The SymbolicConstant MODEL or a Region object specifying the region to which the stop
    #: condition is applied. The default value is MODEL.
    region: SymbolicConstant = MODEL



import typing

class OdbFieldVarList(typing.List[str]):
    """The read-only OdbFieldVarList object is a sequence listing all variables available for
    the current step and frame. Each item in the sequence is itself a sequence fully
    describing the given variable.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.viewports[name].layers[name].odbDisplay.fieldVariables
            session.viewports[name].odbDisplay.fieldVariables
    """

    ...



from .Interaction import Interaction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class ActuatorSensor(Interaction):
    """The ActuatorSensor object defines a single point actuator where the actuation is
    determined by a user subroutine (UEL). The subroutine senses the data at the same point
    as the actuator.
    The ActuatorSensor object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - ELEMENT
        - USER ELEMENT
        - INITIAL CONDITIONS
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the actuator/sensor interaction is
    #: created. **createStepName** must be set to 'Initial'.
    createStepName: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the point at which the constraint is applied.
    point: Region

    #: A String specifying the ActuatorSensorProp object associated with this interaction.
    interactionProperty: str

    #: An Int specifying the number of coordinate components supplied to the user subroutine
    #: (UEL).
    noCoordComponents: int

    #: A Boolean specifying whether the element matrices are symmetric (ON) or unsymmetric
    #: (OFF). The default value is OFF.
    unsymm: Boolean

    #: An Int specifying the number of solution-dependent variables. The default value is 0.
    noSolutionDepVar: int

    #: A String specifying the name of the user subroutine (UEL) that defines the user element.
    userSubUel: str

    #: A String specifying the degrees of freedom, separated by commas.
    dof: str

    #: A sequence of Floats specifying the initial values of the solution-dependent variables.
    solutionDepVars: tuple

    def __init__(
        self,
        name: str,
        createStepName: str,
        point: Region,
        interactionProperty: str,
        noCoordComponents: int,
        unsymm: Boolean,
        noSolutionDepVar: int,
        userSubUel: str,
        dof: str,
        solutionDepVars: tuple,
    ):
        """This method creates an ActuatorSensor object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ActuatorSensor

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the actuator/sensor interaction is
            created. **createStepName** must be set to 'Initial'.
        point
            A :py:class:`~abaqus.Region.Region.Region` object specifying the point at which the constraint is applied.
        interactionProperty
            A String specifying the ActuatorSensorProp object associated with this interaction.
        noCoordComponents
            An Int specifying the number of coordinate components supplied to the user subroutine
            (UEL).
        unsymm
            A Boolean specifying whether the element matrices are symmetric (ON) or unsymmetric
            (OFF). The default value is OFF.
        noSolutionDepVar
            An Int specifying the number of solution-dependent variables. The default value is 0.
        userSubUel
            A String specifying the name of the user subroutine (UEL) that defines the user element.
        dof
            A String specifying the degrees of freedom, separated by commas.
        solutionDepVars
            A sequence of Floats specifying the initial values of the solution-dependent variables.

        Returns
        -------
        ActuatorSensor
            An :py:class:`~abaqus.Interaction.ActuatorSensor.ActuatorSensor` object.
        """
        super().__init__()

    def setValues(self, *args, **kwargs):
        """This method modifies the ActuatorSensor object."""
        ...



from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region


class SizingMemberSize(GeometricRestriction):
    """The SizingMemberSize object defines a sizing member size geometric restriction.
    The SizingMemberSize object is derived from the GeometricRestriction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
    region: Region

    #: A Float specifying the min width.
    minWidth: float

    def __init__(self, name: str, region: Region, minWidth: float):
        """This method creates a SizingMemberSize object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].optimizationTasks[name].SizingMemberSize

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
        minWidth
            A Float specifying the min width.

        Returns
        -------

        Raises
        ------
        """
        super().__init__()

    def setValues(self, *args, **kwargs):
        """This method modifies the sizingMemberSize object."""
        ...



from .Amplitude import Amplitude
from ..UtilityAndView.abaqusConstants import *


class Correlation(Amplitude):
    """A Correlation is an object used to define the cross-correlation as part of the
    definition of random loading.
    The Correlation object is derived from the Amplitude object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].boundaryConditions[name].correlation[i]
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A SymbolicConstant specifying the approach used in the correlation data representation.
    #: Possible values are CORRELATED, MOVING_NOISE, UNCORRELATED, and USER. The default value
    #: is CORRELATED.
    approach: SymbolicConstant = CORRELATED

    #: A tuple of tuples of Floats specifying the real and imaginary part of the scaling
    #: factor. If **approach** = MOVING_NOISE, then **data** represents the noise velocity components
    #: 1, 2, and 3.
    data: float = None

    #: A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
    #: and TOTAL. The default value is STEP.
    timeSpan: SymbolicConstant = STEP



from .....UtilityAndView.abaqusConstants import *


class DruckerPragerCreep:
    r"""The DruckerPragerCreep object specifies creep for Drucker-Prager plasticity models.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].druckerPrager.druckerPragerCreep
            import odbMaterial
            session.odbs[name].materials[name].druckerPrager.druckerPragerCreep

        The table data for this object are:

        - If **law** = TIME or **law** = STRAIN, the table data specify the following:
        
            - A. (Units of :math:`\mathrm{F}^{-n} \mathrm{~L}^{2 n} \mathrm{~T}^{-1-m}`.)
            - :math:`n`.
            - :math:`m`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **law** = SINGHM, the table data specify the following:
        
            - A. (Units of :math:`\mathrm{T}^{-1}`. )
            - :math:`\alpha`. (Units of :math:`F^{-1} L^{2}`.)
            - :math:`m`.
            - :math:`t_{1} \cdot` (Units of :math:`\mathrm{T}`.)
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - DRUCKER PRAGER CREEP
    """

    def __init__(
        self,
        table: tuple,
        law: SymbolicConstant = STRAIN,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a DruckerPragerCreep object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].druckerPrager.DruckerPragerCreep
                session.odbs[name].materials[name].druckerPrager.DruckerPragerCreep

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        law
            A SymbolicConstant specifying the type of data defining the creep law. Possible values
            are:STRAIN, specifying a strain-hardening power law.TIME, specifying a time-hardening
            power law.SINGHM, specifying a Singh-Mitchell type law.USER, specifying the creep law is
            input from user subroutine CREEP.The default value is STRAIN.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        DruckerPragerCreep
            A :py:class:`~abaqus.Material.Plastic.DruckerPrager.Extended.DruckerPragerCreep.DruckerPragerCreep` object.

        Raises
        ------
        RangeError
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the DruckerPragerCreep object.

        Raises
        ------
        RangeError
        """
        ...



from .LoadState import LoadState
from ..UtilityAndView.abaqusConstants import *


class BoltLoadState(LoadState):
    """The BoltLoadState object stores the propagating data of a bolt load in a step. One
    instance of this object is created internally by the BoltLoad object for each step. The
    instance is also deleted internally by the BoltLoad object.
    The BoltLoadState object has no constructor or methods.
    The BoltLoadState object is derived from the LoadState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - CLOAD
        - BOUNDARY
    """

    #: A SymbolicConstant specifying the type of bolt load. Possible values are APPLY_FORCE,
    #: ADJUST_LENGTH, and FIX_LENGTH.
    boltMethod: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the bolt load type. Possible
    #: values are UNSET, SET, UNCHANGED, and MODIFIED.
    boltMethodState: SymbolicConstant = None

    #: A Float specifying the bolt load magnitude.
    magnitude: float = None

    #: A SymbolicConstant specifying the propagation state of the bolt load magnitude. Possible
    #: values are UNSET, SET, UNCHANGED, and MODIFIED.
    magnitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



import typing

class CurrentProbeValues:
    """The CurrentProbeValues object has no constructor. The CurrentProbeValues object is
    created when you import the Visualization module.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.currentProbeValues
    """

    #: A tuple of Floats specifying the values obtained while probing. These values are updated
    #: constantly as the user moves the mouse over the object being probed.
    values: typing.Tuple[float, ...] = None



from .SectionPointArray import SectionPointArray
from ..UtilityAndView.abaqusConstants import *


class FieldLocation:
    """The FieldLocation object specifies locations for which data are available in the field.
    For example, a displacement field will have a FieldLocation object with a **position**
    member value of NODAL. The FieldLocation object has no constructor; it is created
    automatically as an element of the **location** member of a FieldOutput object by the
    addData method of a FieldOutput object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import odbAccess
            session.odbs[name].steps[name].frames[i].fieldOutputs[name].locations[i]
    """

    #: A SymbolicConstant specifying the position of the output in the element. Possible values
    #: are:NODAL, specifying the values calculated at the nodes.INTEGRATION_POINT, specifying
    #: the values calculated at the integration points.ELEMENT_NODAL, specifying the values
    #: obtained by extrapolating results calculated at the integration
    #: points.ELEMENT_FACE.CENTROID, specifying the value at the centroid obtained by
    #: extrapolating results calculated at the integration points.
    position: SymbolicConstant = None

    #: A :py:class:`~abaqus.Odb.SectionPointArray.SectionPointArray` object.
    sectionPoints: SectionPointArray = []



from .Section import Section


class PEGSection(Section):
    """The PEGSection object defines the properties of a solid section.
    The PEGSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - SOLID SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the material.
    material: str

    #: A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
    #: The default value is 1.0.
    thickness: float = 1

    #: A Float specifying the value of the x component of the angle between the bounding
    #: planes, ΔϕxΔ⁢ϕx. The default value is 0.0.
    wedgeAngle1: float = 0

    #: A Float specifying the value of the y component of the angle between the bounding
    #: planes, ΔϕyΔ⁢ϕy. The default value is 0.0.
    wedgeAngle2: float = 0

    def __init__(
        self,
        name: str,
        material: str,
        thickness: float = 1,
        wedgeAngle1: float = 0,
        wedgeAngle2: float = 0,
    ):
        """This method creates a PEGSection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].PEGSection
                session.odbs[name].PEGSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        material
            A String specifying the name of the material.
        thickness
            A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
            The default value is 1.0.
        wedgeAngle1
            A Float specifying the value of the x component of the angle between the bounding
            planes, ΔϕxΔ⁢ϕx. The default value is 0.0.
        wedgeAngle2
            A Float specifying the value of the y component of the angle between the bounding
            planes, ΔϕyΔ⁢ϕy. The default value is 0.0.

        Returns
        -------
        PEGSection
            A :py:class:`~abaqus.Section.PEGSection.PEGSection` object.

        Raises
        ------
        InvalidNameError
        RangeError
        """
        super().__init__()

    def setValues(
        self, thickness: float = 1, wedgeAngle1: float = 0, wedgeAngle2: float = 0
    ):
        """This method modifies the PEGSection object.

        Parameters
        ----------
        thickness
            A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
            The default value is 1.0.
        wedgeAngle1
            A Float specifying the value of the x component of the angle between the bounding
            planes, ΔϕxΔ⁢ϕx. The default value is 0.0.
        wedgeAngle2
            A Float specifying the value of the y component of the angle between the bounding
            planes, ΔϕyΔ⁢ϕy. The default value is 0.0.

        Raises
        ------
        RangeError
        """
        ...



from .Leaf import Leaf
from ..UtilityAndView.abaqusConstants import *


class LeafFromInstanceElementLabels(Leaf):
    """The LeafFromInstanceElementLabels object can be used whenever a Leaf object is expected
    as an argument. Leaf objects are used to specify the items in a display group. Leaf
    objects are constructed as temporary objects, which are then used as arguments to
    DisplayGroup commands.
    The LeafFromInstanceElementLabels object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupMdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    def __init__(self, elementLabels: tuple):
        """This method creates a Leaf object from a sequence of Strings specifying the element
        labels. Leaf objects specify the items in a display group.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromInstanceElementLabels

        Parameters
        ----------
        elementLabels
            A sequence of sequences specifying element labels. Each inner sequence consists of a
            PartInstance object followed by a sequence of Strings specifying element labels.

        Returns
        -------
        LeafFromInstanceElementLabels
            A :py:class:`~abaqus.DisplayGroup.LeafFromInstanceElementLabels.LeafFromInstanceElementLabels` object.
        """
        super().__init__(DEFAULT_MODEL)



from .LoadState import LoadState
from ..UtilityAndView.abaqusConstants import *


class PipePressureState(LoadState):
    """The PipePressureState object stores the propagating data for a pipe pressure in a step.
    One instance of this object is created internally by the PipePressure object for each
    step. The instance is also deleted internally by the PipePressure object.
    The PipePressureState object has no constructor or methods.
    The PipePressureState object is derived from the LoadState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - DSLOAD
        - DLOAD
    """

    #: A Float or a Complex specifying the load magnitude.
    magnitude: float = None

    #: A SymbolicConstant specifying the propagation state of the load magnitude. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    magnitudeState: SymbolicConstant = None

    #: A Float specifying the height of the zero pressure level when the pipe pressure
    #: **distributionType** = HYDROSTATIC.
    hZero: float = None

    #: A SymbolicConstant specifying the propagation state of **hZero**. Possible values are
    #: UNSET, SET, UNCHANGED, and FREED.
    hZeroState: SymbolicConstant = None

    #: A Float specifying the height of the reference pressure level when the pipe pressure
    #: **distributionType** = HYDROSTATIC.
    hReference: float = None

    #: A SymbolicConstant specifying the propagation state of **hReference**. Possible values are
    #: UNSET, SET, UNCHANGED, and FREED.
    hReferenceState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



from ...UtilityAndView.abaqusConstants import *


class Eos:
    r"""The Eos object specifies an equation of state model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].eos
            import odbMaterial
            session.odbs[name].materials[name].eos

        The table data for this object are:

        - If **type** = IDEALGAS, the table data represents the following:
        
            - Gas constant, :math:`R`.
            - The ambient pressure, :math:`p_{A}`. If this field is left blank, a default of 0.0 is used.
            
        - If **type** = JWL, the table data represents the following:
        
            - Detonation wave speed, :math:`C_{d}`.
            - :math:`A`.
            - :math:`B`.
            - :math:`\omega`. (Dimensionless.)
            - :math:`R_{1}`. (Dimensionless.)
            - :math:`R_{2}`. (Dimensionless.)
            - Pre-detonation bulk modulus, :math:`K_{p d}`.
            - Detonation energy density, :math:`E_{0}`.
            
        - If **type** = USUP, the table data represents the following:
        
            - :math:`C_{0}`
            - :math:`\boldsymbol{S}`. (Dimensionless.)
            - :math:`\Gamma_{0}`. (Dimensionless.)
            
        - If **type** = TABULAR, the table data represents the following:
        
            - :math:`F_{1}`
            - :math:`F_{2}`
            - :math:`\varepsilon_{v o l}^{c}`. (Dimensionless.)
    """

    def __init__(
        self,
        type: SymbolicConstant = IDEALGAS,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        detonationEnergy: float = 0,
        solidTable: tuple = (),
        gasTable: tuple = (),
        reactionTable: tuple = (),
        gasSpecificTable: tuple = (),
        table: tuple = (),
    ):
        """This method creates an Eos object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Eos
                session.odbs[name].materials[name].Eos

        Parameters
        ----------
        type
            A SymbolicConstant specifying the equation of state. Possible values are USUP, JWL,
            IDEALGAS, TABULAR, and IGNITIONANDGROWTH. The default value is IDEALGAS.
        temperatureDependency
            A Boolean specifying whether the data in **gasSpecificTable** depend on temperature. The
            default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies for the data in
            **gasSpecificTable**. The default value is 0.
        detonationEnergy
            A Float specifying the detonation energy text field. The default value is 0.0.
        solidTable
            A sequence of sequences of Floats specifying the following:
            
            - :math:`A_{s}`.
            - :math:`B_{s}`.
            - :math:`{\omega}_{s}`.
            - :math:`R_{1s}`.
            - :math:`R_{2s}`.
            
            The default value is an empty sequence.
        gasTable
            A sequence of sequences of Floats specifying the following:
            
            - :math:`A_{g}`.
            - :math:`B_{g}`.
            - :math:`{\omega}_{g}`.
            - :math:`R_{1g}`.
            - :math:`R_{2g}`.
            
            The default value is an empty sequence.
        reactionTable
            A sequence of sequences of Floats specifying the following:
            
            - Initial Pressure, :math:`I`.
            - Product co-volume, :math:`a`.
            - Exponent on the unreacted fraction (ignition term), :math:`x`.
            - First burn rate coefficient, :math:`G_{1}`
            - Exponent on the unreacted fraction (growth term), :math:`c`.
            - Exponent on the reacted fraction (growth term), :math:`d`.
            - Pressure exponent (growth term), :math:`y`.
            - Second burn rate coefficient, :math:`G_{2}`.
            - Exponent on the unreacted fraction (completion term), :math:`e`.
            - Exponent on the reacted fraction (completion term), :math:`g`.
            - Pressure exponent (completion term), :math:`z`.
            - Initial reacted fraction, :math:`{F^{max}}_{ig}`.
            - Maximum reacted fraction for the growth term, :math:`{F^{max}}_{G1}`.
            - Minimum reacted fraction, :math:`{F^{min}}_{G2}`.
            
            The default value is an empty sequence.
        gasSpecificTable
            A sequence of sequences of Floats specifying the following:
            
            - Specific Heat per unit mass.
            - Temperature dependent data.
            - Value of first field variable.
            - Value of second field variable.
            - Etc.
            
            The default value is an empty sequence.
        table
            A sequence of sequences of Floats specifying the items described below. The default
            value is an empty sequence.

        Returns
        -------

        Raises
        ------
        """
        ...



from .CommonOptions import CommonOptions
from .ContourOptions import ContourOptions
from .DisplayBodyOptions import DisplayBodyOptions
from .OrientationOptions import OrientationOptions
from .SuperimposeOptions import SuperimposeOptions
from .SymbolOptions import SymbolOptions
from ..PlotOptions.BasicOptions import BasicOptions
from ..PlotOptions.FreeBodyOptions import FreeBodyOptions
from ..PlotOptions.StreamOptions import StreamOptions
from ..PlotOptions.ViewCutOptions import ViewCutOptions


class DefaultOdbDisplay:
    """The DefaultOdbDisplay object is a limited-functionality version of the OdbDisplay
    object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultOdbDisplay
    """

    #: A :py:class:`~abaqus.PlotOptions.BasicOptions.BasicOptions` object.
    basicOptions: BasicOptions = BasicOptions()

    #: A :py:class:`~abaqus.OdbDisplay.CommonOptions.CommonOptions` object.
    commonOptions: CommonOptions = CommonOptions()

    #: A :py:class:`~abaqus.OdbDisplay.ContourOptions.ContourOptions` object.
    contourOptions: ContourOptions = ContourOptions()

    #: A :py:class:`~abaqus.OdbDisplay.DisplayBodyOptions.DisplayBodyOptions` object.
    displayBodyOptions: DisplayBodyOptions = DisplayBodyOptions()

    #: A :py:class:`~abaqus.PlotOptions.FreeBodyOptions.FreeBodyOptions` object.
    freeBodyOptions: FreeBodyOptions = FreeBodyOptions()

    #: A :py:class:`~abaqus.PlotOptions.StreamOptions.StreamOptions` object.
    streamOptions: StreamOptions = StreamOptions()

    #: An :py:class:`~abaqus.OdbDisplay.OrientationOptions.OrientationOptions` object.
    materialOrientationOptions: OrientationOptions = OrientationOptions()

    #: A :py:class:`~abaqus.OdbDisplay.SuperimposeOptions.SuperimposeOptions` object.
    superimposeOptions: SuperimposeOptions = SuperimposeOptions()

    #: A :py:class:`~abaqus.OdbDisplay.SymbolOptions.SymbolOptions` object.
    symbolOptions: SymbolOptions = SymbolOptions()

    #: A :py:class:`~abaqus.PlotOptions.ViewCutOptions.ViewCutOptions` object.
    viewCutOptions: ViewCutOptions = ViewCutOptions()



import typing

from ..UtilityAndView.abaqusConstants import *


class NormalBehavior:
    """The NormalBehavior object specifies normal behavior for a contact interaction property.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactionProperties[name].normalBehavior

        The table data for this object are:

        - If **pressureOverclosure** = EXPONENTIAL, the table data specify the following:
        
            - Pressure at zero clearance, p0p0.
            - Clearance at which the contact pressure is zero, c0c0.
        - If **pressureOverclosure** = TABULAR, the table data specify the following:
        
            - Pressure.
            - Overclosure.

        The corresponding analysis keywords are:

        - SURFACE BEHAVIOR
    """

    #: The SymbolicConstant DEFAULT or a Float specifying the contact stiffness. This argument
    #: is valid for **pressureOverclosure** = LINEAR. This argument is also valid for
    #: **pressureOverclosure** = HARD when **constraintEnforcementMethod** = AUGMENTED_LAGRANGE or
    #: PENALTY. A value of DEFAULT is valid only when the later conditions are met. A value of
    #: zero is equivalent to specifying DEFAULT. The default value is DEFAULT.
    contactStiffness: typing.Union[SymbolicConstant, float] = DEFAULT

    #: A SymbolicConstant specifying the pressure-overclosure relationship to be used. Possible
    #: values are HARD, EXPONENTIAL, LINEAR, TABULAR, and SCALE_FACTOR. The default value is
    #: HARD.
    pressureOverclosure: SymbolicConstant = HARD

    #: A Boolean specifying whether to allow separation after contact. The default value is ON.
    allowSeparation: Boolean = ON

    #: None or a Float specifying the maximum stiffness. If **maxStiffness** = None, there is no
    #: upper limit. The default value is None.
    maxStiffness: float = None

    #: A sequence of sequences of Floats specifying the normal behavior properties. This
    #: argument is valid only for **pressureOverclosure** = EXPONENTIAL or TABULAR. The items in
    #: the table data are described below.
    table: tuple = ()

    #: A SymbolicConstant specifying the method for enforcement of the contact constraint.
    #: Possible values are DEFAULT, AUGMENTED_LAGRANGE, PENALTY, and DIRECT. The default value
    #: is DEFAULT.
    constraintEnforcementMethod: SymbolicConstant = DEFAULT

    #: A Float specifying the overclosure measure (used to delineate the segments of the
    #: pressure-overclosure curve) as a percentage of the minimum element size in the contact
    #: region. The default value is 0.0.
    overclosureFactor: float = 0

    #: A Float specifying the overclosure measure (used to delineate the segments of the
    #: pressure-overclosure curve) directly. The default value is 0.0.
    overclosureMeasure: float = 0

    #: A Float specifying scale factor for the penalty stiffness or the geometric scaling of
    #: the "base" stiffness. The default value is 1.0.
    contactStiffnessScaleFactor: float = 1

    #: A Float specifying an additional scale factor for the "base" default contact stiffness.
    #: The default value is 1.0.
    initialStiffnessScaleFactor: float = 1

    #: A Float specifying the clearance at which the contact pressure is zero. The default
    #: value is 0.0.
    clearanceAtZeroContactPressure: float = 0

    #: A SymbolicConstant specifying the type of penalty stiffness to be defined. This argument
    #: is valid only when **constraintEnforcementMethod** = PENALTY. Possible values are LINEAR and
    #: NONLINEAR. The default value is LINEAR.
    stiffnessBehavior: SymbolicConstant = LINEAR

    #: A Float specifying the ratio of the initial stiffness divided by the final stiffness.
    #: This argument is valid only when **stiffnessBehavior** = NONLINEAR. Possible values are 0 ≤≤
    #: **stiffnessRatio** << 1. The default value is 0.01.
    stiffnessRatio: float = 0

    #: A Float specifying the ratio of the overclosure at the maximum stiffness divided by the
    #: characteristic facet length. This argument is valid only when
    #: **stiffnessBehavior** = NONLINEAR. The default value is 0.03.
    upperQuadraticFactor: float = 0

    #: A Float specifying the ratio of the overclosure at the initial stiffness divided by the
    #: overclosure at the maximum stiffness, both relative to the clearance at which the
    #: contact pressure is zero. This argument is valid only when
    #: **stiffnessBehavior** = NONLINEAR. Possible values are 0 ≤≤ **stiffnessRatio** << 1. The
    #: default value is 0.33333.
    lowerQuadraticRatio: float = 0

    def __init__(
        self,
        contactStiffness: typing.Union[SymbolicConstant, float] = DEFAULT,
        pressureOverclosure: SymbolicConstant = HARD,
        allowSeparation: Boolean = ON,
        maxStiffness: float = None,
        table: tuple = (),
        constraintEnforcementMethod: SymbolicConstant = DEFAULT,
        overclosureFactor: float = 0,
        overclosureMeasure: float = 0,
        contactStiffnessScaleFactor: float = 1,
        initialStiffnessScaleFactor: float = 1,
        clearanceAtZeroContactPressure: float = 0,
        stiffnessBehavior: SymbolicConstant = LINEAR,
        stiffnessRatio: float = 0,
        upperQuadraticFactor: float = 0,
        lowerQuadraticRatio: float = 0,
    ):
        """This method creates a NormalBehavior object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].interactionProperties[name].NormalBehavior

        Parameters
        ----------
        contactStiffness
            The SymbolicConstant DEFAULT or a Float specifying the contact stiffness. This argument
            is valid for **pressureOverclosure** = LINEAR. This argument is also valid for
            **pressureOverclosure** = HARD when **constraintEnforcementMethod** = AUGMENTED_LAGRANGE or
            PENALTY. A value of DEFAULT is valid only when the later conditions are met. A value of
            zero is equivalent to specifying DEFAULT. The default value is DEFAULT.
        pressureOverclosure
            A SymbolicConstant specifying the pressure-overclosure relationship to be used. Possible
            values are HARD, EXPONENTIAL, LINEAR, TABULAR, and SCALE_FACTOR. The default value is
            HARD.
        allowSeparation
            A Boolean specifying whether to allow separation after contact. The default value is ON.
        maxStiffness
            None or a Float specifying the maximum stiffness. If **maxStiffness** = None, there is no
            upper limit. The default value is None.
        table
            A sequence of sequences of Floats specifying the normal behavior properties. This
            argument is valid only for **pressureOverclosure** = EXPONENTIAL or TABULAR. The items in
            the table data are described below.
        constraintEnforcementMethod
            A SymbolicConstant specifying the method for enforcement of the contact constraint.
            Possible values are DEFAULT, AUGMENTED_LAGRANGE, PENALTY, and DIRECT. The default value
            is DEFAULT.
        overclosureFactor
            A Float specifying the overclosure measure (used to delineate the segments of the
            pressure-overclosure curve) as a percentage of the minimum element size in the contact
            region. The default value is 0.0.
        overclosureMeasure
            A Float specifying the overclosure measure (used to delineate the segments of the
            pressure-overclosure curve) directly. The default value is 0.0.
        contactStiffnessScaleFactor
            A Float specifying scale factor for the penalty stiffness or the geometric scaling of
            the "base" stiffness. The default value is 1.0.
        initialStiffnessScaleFactor
            A Float specifying an additional scale factor for the "base" default contact stiffness.
            The default value is 1.0.
        clearanceAtZeroContactPressure
            A Float specifying the clearance at which the contact pressure is zero. The default
            value is 0.0.
        stiffnessBehavior
            A SymbolicConstant specifying the type of penalty stiffness to be defined. This argument
            is valid only when **constraintEnforcementMethod** = PENALTY. Possible values are LINEAR and
            NONLINEAR. The default value is LINEAR.
        stiffnessRatio
            A Float specifying the ratio of the initial stiffness divided by the final stiffness.
            This argument is valid only when **stiffnessBehavior** = NONLINEAR. Possible values are 0 ≤≤
            **stiffnessRatio** << 1. The default value is 0.01.
        upperQuadraticFactor
            A Float specifying the ratio of the overclosure at the maximum stiffness divided by the
            characteristic facet length. This argument is valid only when
            **stiffnessBehavior** = NONLINEAR. The default value is 0.03.
        lowerQuadraticRatio
            A Float specifying the ratio of the overclosure at the initial stiffness divided by the
            overclosure at the maximum stiffness, both relative to the clearance at which the
            contact pressure is zero. This argument is valid only when
            **stiffnessBehavior** = NONLINEAR. Possible values are 0 ≤≤ **stiffnessRatio** << 1. The
            default value is 0.33333.

        Returns
        -------
        NormalBehavior
            A :py:class:`~abaqus.Interaction.NormalBehavior.NormalBehavior` object.
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the NormalBehavior object."""
        ...



from ..UtilityAndView.abaqusConstants import *


class FreeBodyReportOptions:
    """The FreeBodyReportOptions object stores settings used by the writeFreeBodyReport method
    when you write free body computational results to an ASCII file. The
    FreeBodyReportOptions object has no constructor. Abaqus creates the
    **freeBodyReportOptions** member when you import the Visualization module.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultFreeBodyReportOptions
            session.freeBodyReportOptions
    """

    def setValues(
        self,
        numDigits: int = 3,
        forceThreshold: float = None,
        momentThreshold: float = None,
        numberFormat: SymbolicConstant = SCIENTIFIC,
        reportFormat: SymbolicConstant = NORMAL_ANNOTATED,
        csysType: SymbolicConstant = GLOBAL,
    ):
        """This method modifies the FreeBodyReportOptions object.

        Parameters
        ----------
        numDigits
            An Int specifying the number of decimal places. The default value is 3.
        forceThreshold
            A Float specifying the threshold value for force. The default value is 10-6.
        momentThreshold
            A Float specifying the threshold value for moment. The default value is 10-6.
        numberFormat
            A SymbolicConstant specifying the number format. Possible values are SCIENTIFIC, FIXED,
            and ENGINEERING. The default value is SCIENTIFIC.
        reportFormat
            A SymbolicConstant specifying the report format. Possible values are NORMAL_ANNOTATED
            and COMMA_SEPARATED_VALUES. The default value is NORMAL_ANNOTATED.
        csysType
            A SymbolicConstant specifying the coordinate system type. Possible values are GLOBAL and
            LOCAL. The default value is GLOBAL.

        Returns
        -------
        FreeBodyReportOptions
            A :py:class:`~abaqus.FieldReport.FreeBodyReportOptions.FreeBodyReportOptions` object.
        """
        ...
